import React from "react"
import { graphql, PageProps } from "gatsby"
import dayjs from "dayjs"

import { ArrowCircleLeftIcon } from "@heroicons/react/outline"
import {
    Badge,
    Card,
    Image,
    Button,
    Layout,
    Content,
} from "@onegeo-suite/gatsby-theme-onegeo"

const SideBar = ({ documents, links }) => {
    if (documents?.length == 0 && links?.length == 0) return null
    return (
        <div className="bg-base-100 sticky top-24 flex h-full flex-col rounded-xl shadow-lg md:w-1/4">
            {documents?.length > 0 && (
                <div className="p-6">
                    <p className="text-base-300 text-sm font-bold uppercase tracking-widest">
                        Téléchargements
                    </p>
                    <div className="mt-2 ">
                        {documents.map((item: any, key: number) => {
                            return (
                                <ul className="leading-8" key={key}>
                                    <li>
                                        {
                                            item.directus_files_id
                                                .filename_download
                                        }
                                    </li>
                                </ul>
                            )
                        })}
                    </div>
                </div>
            )}

            {links?.length > 0 && (
                <div className="p-6">
                    <p className="text-base-300 text-sm font-bold uppercase tracking-widest">
                        Liens
                    </p>
                    <div className="mt-2 ">
                        {links.map((item: any) => {
                            return (
                                <ul className="leading-8" key={item.id}>
                                    <li>{item.links_id.url}</li>
                                </ul>
                            )
                        })}
                    </div>
                </div>
            )}
        </div>
    )
}

interface Idata {
    directus: {
        news: {
            id: string
            title: string
            date_published: string
            author: string
            image: {
                id: string
                imageFile: {
                    publicURL: string
                }
            }
            links: {
                id: string
                links_id: {
                    url: string
                }
            }
            documents: {
                directus_files_id: {
                    filename_download: string
                }
            }
            categories: {
                name: string
            }
            content: string
            link: string
        }
    }
}

// http://localhost:8000/news/avancement-bd-ortho-2021 (avec doc)
// http://localhost:8000/news/mise-a-disposition-des-ortho-images-de-2015-sur-la-cacl (sans doc)

const News = ({ pageContext, data, location }: PageProps<Idata>) => {
    const news = data.directus.news[0]

    const urlImage = data.directus.news[0].image?.imageFile?.publicURL
    const categoryName = data.directus.news[0].categories?.name

    const { content, title, author, links, documents, date_published } = news

    const dataPub = dayjs(date_published).format("DD/MM/YYYY")

    let position = "right"

    return (
        <Layout>
            <Content className="pt-8">
                <div className="bg-base-100 rounded-xl p-6 shadow-lg">
                    <Button
                        aria-label="Retour"
                        className="btn-ghost text-primary gap-2 font-bold normal-case"
                        url="/news"
                    >
                        <ArrowCircleLeftIcon
                            className="mr-2 h-6 w-6"
                            aria-hidden="true"
                        />
                        Toutes les actualités
                    </Button>

                    <p className="text-xl font-bold sm:text-2xl md:text-3xl">
                        {title}
                    </p>
                    <p className="text-primary mt-2 text-sm font-semibold tracking-wide">
                        Soumis par {author} le {dataPub}
                    </p>
                    <Badge title={categoryName} className="badge-lg mt-2" />
                </div>

                <div className="mt-8 mb-8 flex flex-wrap gap-6 md:flex-nowrap">
                    {position === "left" ? (
                        <SideBar documents={documents} links={links} />
                    ) : null}

                    <div
                        className={`w-full  ${
                            documents?.length > 0 || links?.length > 0
                                ? "md:w-3/4"
                                : "w-full"
                        }`}
                    >
                        <div className="bg-base-100 rounded-xl p-6 shadow-lg">
                            <div
                                data-typesense-field="description"
                                className="prose max-w-4xl"
                                dangerouslySetInnerHTML={{
                                    __html: content,
                                }}
                            ></div>
                        </div>
                    </div>

                    {position === "right" ? (
                        <SideBar documents={documents} links={links} />
                    ) : null}
                </div>
                <div className="mb-24 flex justify-center">
                    <div className="flex w-5/6 space-x-4">
                        <Card
                            url={"/news/" + pageContext.prev?.slug}
                            name="Précédent"
                            description={pageContext.prev?.title}
                            layout="left"
                            size="xs"
                            image={
                                pageContext.prev?.image != null
                                    ? pageContext.prev?.image?.imageFile
                                          ?.publicURL
                                    : "mock"
                            }
                        />
                        {pageContext.next ? (
                            <Card
                                url={"/news/" + pageContext.next?.slug}
                                name="Suivant"
                                description={pageContext.next?.title}
                                layout="left"
                                size="xs"
                                image={
                                    pageContext.next?.image != null
                                        ? pageContext.next?.image?.imageFile
                                              ?.publicURL
                                        : "mock"
                                }
                            />
                        ) : null}
                    </div>
                </div>
            </Content>
        </Layout>
    )
}

export default News

export const query = graphql`
    query ($id: DirectusData_GraphQLStringOrFloat!) {
        directus {
            news(filter: { id: { _eq: $id } }) {
                id
                title
                content
                date_published
                author
                image {
                    id
                    imageFile {
                        publicURL
                    }
                }
                links {
                    id
                    links_id {
                        url
                    }
                }
                documents {
                    directus_files_id {
                        filename_download
                    }
                }
                categories {
                    name
                }
            }
        }
    }
`
